@@ -24,7 +24,7 @@
 #include <unistd.h>
 #include "file-utils.h"
 #include "fr-stock.h"
-#include "main.h"
+#include "fr-init.h"
 #include "gtk-utils.h"
 #include "fr-window.h"
 #include "typedefs.h"
