@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <string.h>
@@ -180,7 +179,8 @@ base_fr_command_get_mime_types (FrCommand *comm)
 
 FrCommandCap
 base_fr_command_get_capabilities (FrCommand  *comm,
-			          const char *mime_type)
+			          const char *mime_type,
+			          gboolean    check_command)
 {
 	return FR_COMMAND_CAN_DO_NOTHING;
 }
@@ -195,6 +195,14 @@ base_fr_command_set_mime_type (FrCommand  *comm,
 }
 
 
+static const char *
+base_fr_command_get_packages (FrCommand  *comm,
+			      const char *mime_type)
+{
+	return NULL;
+}
+
+
 static void
 fr_command_start (FrProcess *process,
 		  gpointer   data)
@@ -370,6 +378,7 @@ fr_command_class_init (FrCommandClass *class)
 	class->get_mime_types   = base_fr_command_get_mime_types;
 	class->get_capabilities = base_fr_command_get_capabilities;
 	class->set_mime_type    = base_fr_command_set_mime_type;
+	class->get_packages     = base_fr_command_get_packages;
 	class->start            = NULL;
 	class->done             = NULL;
 	class->progress         = NULL;
@@ -712,15 +721,16 @@ fr_command_get_mime_types (FrCommand *comm)
 void
 fr_command_update_capabilities (FrCommand *comm)
 {
-	comm->capabilities = fr_command_get_capabilities (comm, comm->mime_type);
+	comm->capabilities = fr_command_get_capabilities (comm, comm->mime_type, TRUE);
 }
 
 
 FrCommandCap
 fr_command_get_capabilities (FrCommand  *comm,
-			     const char *mime_type)
+			     const char *mime_type,
+			     gboolean    check_command)
 {
-	return FR_COMMAND_GET_CLASS (G_OBJECT (comm))->get_capabilities (comm, mime_type);
+	return FR_COMMAND_GET_CLASS (G_OBJECT (comm))->get_capabilities (comm, mime_type, check_command);
 }
 
 
@@ -732,6 +742,14 @@ fr_command_is_capable_of (FrCommand     *comm,
 }
 
 
+const char *
+fr_command_get_packages (FrCommand  *comm,
+			 const char *mime_type)
+{
+	return FR_COMMAND_GET_CLASS (G_OBJECT (comm))->get_packages (comm, mime_type);
+}
+
+
 /* fraction == -1 means : I don't known how much time the current operation
  *                        will take, the dialog will display this info pulsing
  *                        the progress bar.
