@@ -29,7 +29,7 @@ fr_error_quark (void)
 	static GQuark quark;
         
         if (!quark)
-                quark = g_quark_from_static_string ("file_roller_error");
+                quark = g_quark_from_static_string ("file-roller-error");
 	
         return quark;
 }
